/*
 * IRC - Internet Relay Chat, include/ircd.h
 *
 * See file doc/authors for names of the programmers.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef IRCD_H
#define IRCD_H

/*=============================================================================
 * Macro's
 */

#define TStime() (now + TSoffset)
#define BadPtr(x) (!(x) || (*(x) == '\0'))

/* Miscellaneous defines */

#define UDP_PORT	"7007"
#define MINOR_PROTOCOL	"09"
#define MAJOR_PROTOCOL	"10"
#define BASE_VERSION	"u2.10"

#define REPORT_DO_DNS	"NOTICE AUTH :*** Looking up your hostname...\r\n"
#define REPORT_FIN_DNS	"NOTICE AUTH :*** Found your hostname\r\n"
#define REPORT_FIN_DNSC	"NOTICE AUTH :*** Found your hostname (cached)\r\n"
#define REPORT_FAIL_DNS	"NOTICE AUTH :*** Couldn't look up your hostname\r\n"
#define REPORT_DO_ID	"NOTICE AUTH :*** Checking Ident...\r\n"
#define REPORT_FIN_ID	"NOTICE AUTH :*** Got Ident response\r\n"
#define REPORT_FAIL_ID	"NOTICE AUTH :*** No Ident response\r\n"

/* Flags for bootup options (command line flags) */

#define BOOT_CONSOLE	1
#define BOOT_QUICK	2
#define BOOT_DEBUG	4
#define BOOT_INETD	8
#define BOOT_TTY	16
#define BOOT_OPER	32
#define BOOT_AUTODIE	64

/*=============================================================================
 * Proto types
 */

#ifdef PROFIL
extern RETSIGTYPE s_monitor(HANDLER_ARG(int sig));
#endif
extern RETSIGTYPE s_die(HANDLER_ARG(int sig));
extern RETSIGTYPE s_restart(HANDLER_ARG(int sig));

extern void restart(char *mesg);
extern void server_reboot(void);

extern aClient me;
extern time_t now;
extern aClient *client;
extern time_t TSoffset;
extern unsigned int bootopt;
extern time_t nextdnscheck;
extern time_t nextconnect;
extern int dorehash;
extern time_t nextping;
extern unsigned short int portnum;
extern char *configfile;
extern int debuglevel;
extern char *debugmode;

#endif /* IRCD_H */
